@@ -156,6 +156,15 @@ class HyperV:
             return False
         return True
 
+    # Поставить машины на паузу по маске или передав список машин
+    def vm_restart(self, vms=[]):
+        ps_script = self.gen_job(vms_list=vms, job='Restart-VM', force=True)
+        result = self.session.run_ps(ps_script)
+        logging.debug(f"result std_out\n{result.std_out.decode('utf-8')}")
+        logging.debug(f"result status_code \n{result.status_code}")
+        if result.status_code == '1':
+            return False
+        return True
     
     
     # Снять машины с паузы по маске или передав список машин
@@ -195,7 +204,9 @@ class HyperV:
             if 'current_snapshot' in kwargs.keys(): params = f"| select Name, ParentSnapshotName"
             if 'dellete_snapshots' in kwargs.keys(): params = f"| Remove-VMSnapshot -Name {kwargs['dellete_snapshots']}"
             if 'apply_snapshots' in kwargs.keys(): params = f"| Restore-VMSnapshot -Name  {kwargs['apply_snapshots']} -Confirm:$false"
-            # if 'state' in kwargs.keys():
+            
+            if 'force' in kwargs.keys():
+                params = '-Force'
 
         all_vms = f"{self.env_prefix}* "
 
